@@ -1,5 +1,5 @@
 /* libwpd
- * Copyright (C) 2003 William Lachance (william.lachance@sympatico.ca)
+ * Copyright (C) 2003 William Lachance (wrlach@gmail.com)
  * Copyright (C) 2003 Marc Maurer (uwog@uwog.net)
  *  
  * This library is free software; you can redistribute it and/or
@@ -32,7 +32,8 @@
 class WP42Heuristics
 {
 public:
-	static WPDConfidence isWP42FileFormat(WPXInputStream *input, bool partialContent);
+	static WPDConfidence isWP42FileFormat(WPXInputStream *input, const char *password = 0);
+	static WPDPasswordMatch verifyPassword(WPXInputStream *input, const char *password);
 };
 
 #endif /* WP42HEURISTICS_H */
