@@ -26,8 +26,8 @@
 #include "WP6UnsupportedFixedLengthGroup.h"
 #include "libwpd_internal.h"
 
-WP6UnsupportedFixedLengthGroup::WP6UnsupportedFixedLengthGroup(WPXInputStream *input, uint8_t groupID)
+WP6UnsupportedFixedLengthGroup::WP6UnsupportedFixedLengthGroup(WPXInputStream *input, WPXEncryption *encryption, uint8_t groupID)
 	: WP6FixedLengthGroup(groupID)
 {
-	_read(input);
+	_read(input, encryption);
 }
